==> jc-1.4.0.tar.gz: gnu/java/net/protocol/http/Headers__24Header.h <==
// class gnu.java.net.protocol.http.Headers$Header

// class file dependencies
// @dep_class e6f5eea913f0f45b gnu_java_net_protocol_http_Headers__24Header
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_Headers__24Header_H_
#define _JC_gnu_java_net_protocol_http_Headers__24Header_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_Headers__24Header$sub_refs	_jc_gnu_java_net_protocol_http_Headers__24Header$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24Header$sub_nonrefs	_jc_gnu_java_net_protocol_http_Headers__24Header$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24Header$refs	_jc_gnu_java_net_protocol_http_Headers__24Header$refs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24Header$nonrefs	_jc_gnu_java_net_protocol_http_Headers__24Header$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24Header$object	_jc_gnu_java_net_protocol_http_Headers__24Header$object;

typedef const struct _jc_gnu_java_net_protocol_http_Headers__24Header$vmethods	_jc_gnu_java_net_protocol_http_Headers__24Header$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_Headers__24Header$vtable	_jc_gnu_java_net_protocol_http_Headers__24Header$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_Headers__24Header$vtype	_jc_gnu_java_net_protocol_http_Headers__24Header$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_Headers__24Header$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24Header$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_gnu_java_net_protocol_http_Headers__24Header$method$equals$8a15e0625571c581(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24Header$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_gnu_java_net_protocol_http_Headers__24Header$method$hashCode$53152098849316df(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24Header$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_http_Headers__24Header$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24Header$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24Header$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24Header$method_info$hashCode$53152098849316df;
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24Header$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_Headers__24Header$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24Header$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24Header$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24Header$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_http_Headers__24Header$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_Headers__24Header$vmethods	gnu_java_net_protocol_http_Headers__24Header;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_Headers__24Header$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_Headers__24Header$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_Headers__24Header$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_Headers__24Header$refs {
    _jc_gnu_java_net_protocol_http_Headers__24Header$sub_refs	gnu_java_net_protocol_http_Headers__24Header;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_Headers__24Header$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_Headers__24Header$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_Headers__24Header$sub_nonrefs	gnu_java_net_protocol_http_Headers__24Header;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_Headers__24Header$object {
	_jc_gnu_java_net_protocol_http_Headers__24Header$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_Headers__24Header$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_Headers__24Header$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_Headers__24Header$vtype _jc_gnu_java_net_protocol_http_Headers__24Header$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_Headers__24Header, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_Headers__24Header$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_Headers__24Header_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/http/Headers__24Header.h <==
// class gnu.java.net.protocol.http.Headers$Header

// class file dependencies
// @dep_class e6f5eea913f0f45b gnu_java_net_protocol_http_Headers__24Header
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_Headers__24Header_H_
#define _JC_gnu_java_net_protocol_http_Headers__24Header_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_Headers__24Header$sub_refs	_jc_gnu_java_net_protocol_http_Headers__24Header$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24Header$sub_nonrefs	_jc_gnu_java_net_protocol_http_Headers__24Header$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24Header$refs	_jc_gnu_java_net_protocol_http_Headers__24Header$refs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24Header$nonrefs	_jc_gnu_java_net_protocol_http_Headers__24Header$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24Header$object	_jc_gnu_java_net_protocol_http_Headers__24Header$object;

typedef const struct _jc_gnu_java_net_protocol_http_Headers__24Header$vmethods	_jc_gnu_java_net_protocol_http_Headers__24Header$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_Headers__24Header$vtable	_jc_gnu_java_net_protocol_http_Headers__24Header$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_Headers__24Header$vtype	_jc_gnu_java_net_protocol_http_Headers__24Header$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_Headers__24Header$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24Header$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_net_protocol_http_Headers__24Header$method$equals$8a15e0625571c581(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24Header$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_http_Headers__24Header$method$hashCode$53152098849316df(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24Header$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_http_Headers__24Header$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24Header$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24Header$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24Header$method_info$hashCode$53152098849316df;
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24Header$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_Headers__24Header$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24Header$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24Header$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24Header$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_http_Headers__24Header$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_Headers__24Header$vmethods	gnu_java_net_protocol_http_Headers__24Header;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_Headers__24Header$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_Headers__24Header$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_Headers__24Header$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_Headers__24Header$refs {
    _jc_gnu_java_net_protocol_http_Headers__24Header$sub_refs	gnu_java_net_protocol_http_Headers__24Header;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_Headers__24Header$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_Headers__24Header$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_Headers__24Header$sub_nonrefs	gnu_java_net_protocol_http_Headers__24Header;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_Headers__24Header$object {
	_jc_gnu_java_net_protocol_http_Headers__24Header$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_Headers__24Header$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_Headers__24Header$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_Headers__24Header$vtype _jc_gnu_java_net_protocol_http_Headers__24Header$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_Headers__24Header, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_Headers__24Header$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_Headers__24Header_H_ */
